@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2020-2021 Graz University of Technology.
+# Copyright (C) 2020-2022 Graz University of Technology.
 #
 # invenio-config-tugraz is free software; you can redistribute it and/or
 # modify it under the terms of the MIT License; see LICENSE file for more
@@ -8,9 +8,7 @@
 
 """invenio module that adds tugraz configs."""
 
-from os.path import abspath, dirname, join
-
-from flask_babelex import lazy_gettext as _
+from flask_babelex import gettext as _
 
 INVENIO_CONFIG_TUGRAZ_SHIBBOLETH = False
 """Set True if SAML is configured"""
@@ -180,6 +178,9 @@ SECURITY_CONFIRMABLE = False
 Instead user will get a welcome email.
 """
 
+SECURITY_LOGIN_WITHOUT_CONFIRMATION = False
+"""Require users to confirm email before being able to login."""
+
 # Flask-Security
 # =============
 # See https://pythonhosted.org/Flask-Security/configuration.html
@@ -260,7 +261,7 @@ If the value is callable, its return value will be used for the field
 (e.g. lambda/function for dynamic calculation of values).
 """
 
-APP_RDM_DEPOSIT_FORM_AUTOCOMPLETE_NAMES = 'off'
+APP_RDM_DEPOSIT_FORM_AUTOCOMPLETE_NAMES = "off"
 """Behavior for autocomplete names search field for creators/contributors.
 
 Available options:
@@ -271,6 +272,17 @@ Available options:
 - ``off``: Only show person form (no search field).
 """
 
+APP_RDM_DEPOSIT_FORM_QUOTA = {
+    "maxFiles": 100,
+    # Easiest way to set this to a certain amount is to start from 1 Gb
+    # and go from there:
+    #   1 Gb: 10 ** 9
+    #  50 Gb: 10 ** 9 * 50
+    # 100 Mb: 10 ** 9 * 0.1
+    "maxStorage": 10**9 * 10,
+}
+"""Deposit file upload quota """
+
 SQLALCHEMY_ECHO = False
 """Enable to see all SQL queries."""
 
@@ -342,7 +354,7 @@ RATELIMIT_AUTHENTICATED_USER = "25000 per hour;1000 per minute"
 RATELIMIT_GUEST_USER = "5000 per hour;500 per minute"
 """Increase defaults for guest users."""
 
-SESSION_COOKIE_SAMESITE = 'Strict'
+SESSION_COOKIE_SAMESITE = "Strict"
 """Sets cookie with the samesite flag to 'Strict' by default."""
 
 
@@ -354,7 +366,7 @@ OAISERVER_ID_PREFIX = "repository.tugraz.at"
 """The prefix that will be applied to the generated OAI-PMH ids."""
 
 OAISERVER_ADMIN_EMAILS = [
-    'oai@repository.tugraz.at',
+    "oai@repository.tugraz.at",
 ]
 """The e-mail addresses of administrators of the repository.
 
